==========
haggregate
==========


.. image:: https://img.shields.io/pypi/v/haggregate.svg
        :target: https://pypi.python.org/pypi/haggregate

.. image:: https://img.shields.io/travis/openmeteo/haggregate.svg
        :target: https://travis-ci.org/openmeteo/haggregate

.. image:: https://codecov.io/github/openmeteo/haggregate/coverage.svg
        :target: https://codecov.io/gh/openmeteo/haggregate
        :alt: Coverage

.. image:: https://pyup.io/repos/github/openmeteo/haggregate/shield.svg
         :target: https://pyup.io/repos/github/openmeteo/haggregate/
         :alt: Updates

Aggregates htimeseries to larger steps


* Free software: GNU General Public License v3
* Documentation: https://haggregate.readthedocs.io.
